Class: Google::Apis::ChromeuxreportV1::QueryHistoryRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromeuxreport_v1/classes.rb,
lib/google/apis/chromeuxreport_v1/representations.rb,
lib/google/apis/chromeuxreport_v1/representations.rb

Overview

Request payload sent by a physical web client. This request includes all necessary context to load a particular user experience history record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryHistoryRequest

Returns a new instance of QueryHistoryRequest.



422
423
424
# File 'lib/google/apis/chromeuxreport_v1/classes.rb', line 422

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_period_countFixnum

The number of collection periods to return. If not specified, the default is

  1. If present, must be in the range [1, 40]. Corresponds to the JSON property collectionPeriodCount

Returns:

  • (Fixnum)


392
393
394
# File 'lib/google/apis/chromeuxreport_v1/classes.rb', line 392

def collection_period_count
  @collection_period_count
end

#form_factorString

The form factor is a query dimension that specifies the device class that the record's data should belong to. Note: If no form factor is specified, then a special record with aggregated data over all form factors will be returned. Corresponds to the JSON property formFactor

Returns:

  • (String)


399
400
401
# File 'lib/google/apis/chromeuxreport_v1/classes.rb', line 399

def form_factor
  @form_factor
end

#metricsArray<String>

The metrics that should be included in the response. If none are specified then any metrics found will be returned. Allowed values: [" first_contentful_paint", "first_input_delay", "largest_contentful_paint", " cumulative_layout_shift", "experimental_time_to_first_byte", " experimental_interaction_to_next_paint"] Corresponds to the JSON property metrics

Returns:

  • (Array<String>)


408
409
410
# File 'lib/google/apis/chromeuxreport_v1/classes.rb', line 408

def metrics
  @metrics
end

#originString

The url pattern "origin" refers to a url pattern that is the origin of a website. Examples: "https://example.com", "https://cloud.google.com" Corresponds to the JSON property origin

Returns:

  • (String)


414
415
416
# File 'lib/google/apis/chromeuxreport_v1/classes.rb', line 414

def origin
  @origin
end

#urlString

The url pattern "url" refers to a url pattern that is any arbitrary url. Examples: "https://example.com/", "https://cloud.google.com/why-google-cloud/" Corresponds to the JSON property url

Returns:

  • (String)


420
421
422
# File 'lib/google/apis/chromeuxreport_v1/classes.rb', line 420

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



427
428
429
430
431
432
433
# File 'lib/google/apis/chromeuxreport_v1/classes.rb', line 427

def update!(**args)
  @collection_period_count = args[:collection_period_count] if args.key?(:collection_period_count)
  @form_factor = args[:form_factor] if args.key?(:form_factor)
  @metrics = args[:metrics] if args.key?(:metrics)
  @origin = args[:origin] if args.key?(:origin)
  @url = args[:url] if args.key?(:url)
end