Class: Google::Apis::ChromeuxreportV1::TimeseriesPercentiles
- Inherits:
-
Object
- Object
- Google::Apis::ChromeuxreportV1::TimeseriesPercentiles
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromeuxreport_v1/classes.rb,
lib/google/apis/chromeuxreport_v1/representations.rb,
lib/google/apis/chromeuxreport_v1/representations.rb
Overview
Percentiles contains synthetic values of a metric at a given statistical percentile. These are used for estimating a metric's value as experienced by a percentage of users out of the total number of users.
Instance Attribute Summary collapse
-
#p75s ⇒ Array<Object>
75% of users experienced the given metric at or below this value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimeseriesPercentiles
constructor
A new instance of TimeseriesPercentiles.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimeseriesPercentiles
Returns a new instance of TimeseriesPercentiles.
653 654 655 |
# File 'lib/google/apis/chromeuxreport_v1/classes.rb', line 653 def initialize(**args) update!(**args) end |
Instance Attribute Details
#p75s ⇒ Array<Object>
75% of users experienced the given metric at or below this value. The length
of this list of densities is equal to the length of the CollectionPeriods
field in the HistoryRecord message, which describes when the density was
observed in the field.
Corresponds to the JSON property p75s
651 652 653 |
# File 'lib/google/apis/chromeuxreport_v1/classes.rb', line 651 def p75s @p75s end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
658 659 660 |
# File 'lib/google/apis/chromeuxreport_v1/classes.rb', line 658 def update!(**args) @p75s = args[:p75s] if args.key?(:p75s) end |